0.9.9 API documentation: norm.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
norm.hpp File Reference

GLM_GTX_norm More...

Go to the source code of this file.

## Functions
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL T | distance2 (vec< L, T, Q > const &p0, vec< L, T, Q > const &p1)
| Returns the squared distance between p0 and p1, i.e., length2(p0 - p1). More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | l1Norm (vec< 3, T, Q > const &x, vec< 3, T, Q > const &y)
| Returns the L1 norm between x and y. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | l1Norm (vec< 3, T, Q > const &v)
| Returns the L1 norm of v. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | l2Norm (vec< 3, T, Q > const &x, vec< 3, T, Q > const &y)
| Returns the L2 norm between x and y. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | l2Norm (vec< 3, T, Q > const &x)
| Returns the L2 norm of v. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL T | length2 (vec< L, T, Q > const &x)
| Returns the squared length of x. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | lMaxNorm (vec< 3, T, Q > const &x, vec< 3, T, Q > const &y)
| Returns the LMax norm between x and y. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | lMaxNorm (vec< 3, T, Q > const &x)
| Returns the LMax norm of v. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | lxNorm (vec< 3, T, Q > const &x, vec< 3, T, Q > const &y, unsigned int Depth)
| Returns the L norm between x and y. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | lxNorm (vec< 3, T, Q > const &x, unsigned int Depth)
| Returns the L norm of v. More...

## Detailed Description

GLM_GTX_norm

See also
  Core features (dependence)
  GLM_GTX_quaternion (dependence)
  GLM_GTX_component_wise (dependence)

Definition in file norm.hpp.